@@ -143,6 +143,15 @@ START_TEST(test_code_snd_name)
 }
 END_TEST
 
+START_TEST(test_code_rep_name)
+{
+	ck_assert_str_eq(libevdev_event_code_get_name(EV_REP, REP_DELAY), "REP_DELAY");
+	ck_assert_str_eq(libevdev_event_code_get_name(EV_REP, REP_PERIOD), "REP_PERIOD");
+	ck_assert_str_eq(libevdev_event_code_get_name(EV_REP, REP_MAX), "REP_PERIOD");
+
+}
+END_TEST
+
 START_TEST(test_code_msc_name)
 {
 	/* pick out a few only */
@@ -164,7 +173,8 @@ START_TEST(test_code_sw_name)
 	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_LID), "SW_LID");
 	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_RFKILL_ALL), "SW_RFKILL_ALL");
 	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_LINEIN_INSERT), "SW_LINEIN_INSERT");
-	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_MAX), "SW_MAX");
+	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_PEN_INSERTED), "SW_PEN_INSERTED");
+	ck_assert_str_eq(libevdev_event_code_get_name(EV_SW, SW_MAX), "SW_PEN_INSERTED");
 }
 END_TEST
 
@@ -281,6 +291,7 @@ event_name_suite(void)
 	tcase_add_test(tc, test_code_key_name);
 	tcase_add_test(tc, test_code_led_name);
 	tcase_add_test(tc, test_code_snd_name);
+	tcase_add_test(tc, test_code_rep_name);
 	tcase_add_test(tc, test_code_msc_name);
 	tcase_add_test(tc, test_code_sw_name);
 	tcase_add_test(tc, test_code_ff_name);
